diff --git a/game/core/src/main/java/net/minecraft/core/block/entity/TileEntityTrommel.java b/game/core/src/main/java/net/minecraft/core/block/entity/TileEntityTrommel.java
index f6e0a888b..0ae26536f 100644
--- a/game/core/src/main/java/net/minecraft/core/block/entity/TileEntityTrommel.java
+++ b/game/core/src/main/java/net/minecraft/core/block/entity/TileEntityTrommel.java
@@ -354,8 +354,6 @@ public class TileEntityTrommel extends TileEntity
 
     private ItemStack getItemResult(ItemStack slotItem)
     {
-        if(random.nextInt(2) != 0)
-            return null;
         List<RecipeEntryTrommel> list = Registries.RECIPES.getAllTrommelRecipes();
         for (RecipeEntryTrommel recipe : list) {
             if(recipe.getInput().matches(slotItem)){
@@ -516,6 +514,20 @@ public class TileEntityTrommel extends TileEntity
         TileEntityTrommel trommel = new TileEntityTrommel();
         trommel.worldObj = new World();
 
+        trommel.simulateTrommelDrops(10000, Blocks.MUD.getDefaultStack());
+        trommel.simulateTrommelDrops(10000, Blocks.DIRT.getDefaultStack());
+        trommel.simulateTrommelDrops(10000, Blocks.GRAVEL.getDefaultStack());
+        trommel.simulateTrommelDrops(10000, Blocks.SAND.getDefaultStack());
+        trommel.simulateTrommelDrops(10000, Blocks.SOULSAND.getDefaultStack());
+        trommel.simulateTrommelDrops(10000, Blocks.BLOCK_CLAY.getDefaultStack());
+        trommel.simulateTrommelDrops(10000, Blocks.DIRT_SCORCHED_RICH.getDefaultStack());
+    }
+
+    public static void simulate() {
+        TileEntityTrommel trommel = new TileEntityTrommel();
+        trommel.worldObj = new World();
+
+        trommel.simulateTrommelDrops(10000, Blocks.MUD.getDefaultStack());
         trommel.simulateTrommelDrops(10000, Blocks.DIRT.getDefaultStack());
         trommel.simulateTrommelDrops(10000, Blocks.GRAVEL.getDefaultStack());
         trommel.simulateTrommelDrops(10000, Blocks.SAND.getDefaultStack());
diff --git a/game/core/src/main/java/net/minecraft/core/data/registry/Registries.java b/game/core/src/main/java/net/minecraft/core/data/registry/Registries.java
index 319bb69a7..bfc8547ba 100644
--- a/game/core/src/main/java/net/minecraft/core/data/registry/Registries.java
+++ b/game/core/src/main/java/net/minecraft/core/data/registry/Registries.java
@@ -70,7 +70,7 @@ public class Registries extends Registry<Registry<?>>
         ITEM_GROUPS.register("minecraft:cobblestones",stackListOf(Blocks.COBBLE_STONE, Blocks.COBBLE_BASALT, Blocks.COBBLE_LIMESTONE, Blocks.COBBLE_GRANITE, Blocks.COBBLE_PERMAFROST, Blocks.COBBLE_NETHERRACK));
         ITEM_GROUPS.register("minecraft:grasses",stackListOf(Blocks.GRASS, Blocks.GRASS_RETRO));
         ITEM_GROUPS.register("minecraft:dirt",stackListOf(Blocks.DIRT, Blocks.DIRT_SCORCHED));
-        ITEM_GROUPS.register("minecraft:trommel_dirt",stackListOf(Blocks.DIRT, Blocks.DIRT_SCORCHED, Blocks.GRASS, Blocks.GRASS_RETRO, Blocks.GRASS_SCORCHED, Blocks.PATH_DIRT, Blocks.FARMLAND_DIRT, Blocks.MUD));
+        ITEM_GROUPS.register("minecraft:trommel_dirt",stackListOf(Blocks.DIRT, Blocks.DIRT_SCORCHED, Blocks.GRASS, Blocks.GRASS_RETRO, Blocks.GRASS_SCORCHED, Blocks.PATH_DIRT, Blocks.FARMLAND_DIRT));
         ITEM_GROUPS.register("minecraft:moss_stones",stackListOf(Blocks.MOSS_STONE, Blocks.MOSS_BASALT, Blocks.MOSS_LIMESTONE, Blocks.MOSS_GRANITE));
         ITEM_GROUPS.register("minecraft:logs",stackListOf(Blocks.LOG_OAK, Blocks.LOG_PINE, Blocks.LOG_BIRCH, Blocks.LOG_CHERRY, Blocks.LOG_EUCALYPTUS, Blocks.LOG_OAK_MOSSY, Blocks.LOG_THORN, Blocks.LOG_PALM));
         ITEM_GROUPS.register("minecraft:leaves",stackListOf(Blocks.LEAVES_OAK, Blocks.LEAVES_OAK_RETRO, Blocks.LEAVES_PINE, Blocks.LEAVES_BIRCH, Blocks.LEAVES_CHERRY, Blocks.LEAVES_EUCALYPTUS, Blocks.LEAVES_SHRUB));
diff --git a/util/datagen/src/main/java/net/minecraft/datagen/TrommelGenerator.java b/util/datagen/src/main/java/net/minecraft/datagen/TrommelGenerator.java
index e2672c000..1252820ff 100644
--- a/util/datagen/src/main/java/net/minecraft/datagen/TrommelGenerator.java
+++ b/util/datagen/src/main/java/net/minecraft/datagen/TrommelGenerator.java
@@ -11,29 +11,40 @@ public class TrommelGenerator {
     public static void generate() {
         RecipeBuilder.Trommel(RecipesGenerator.CORE_NAMESPACE)
             .setInput(Blocks.BLOCK_CLAY)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLAY), 4, 8), 30)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 3), 20)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLAY), 2, 4), 30)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 2), 15)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.GUNPOWDER), 1), 10)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.ORE_RAW_GOLD), 1), 1)
             .create("clay");
 
         RecipeBuilder.Trommel(RecipesGenerator.CORE_NAMESPACE)
             .setInput("minecraft:trommel_dirt")
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 3), 50)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLAY), 1, 5), 20)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.FLINT), 1, 3), 10)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 2), 35)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLAY), 1, 4), 15)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.FLINT), 1, 2), 7.5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.GUNPOWDER), 1), 2)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.ORE_RAW_IRON), 1), 0.5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.OLIVINE), 1), 0.25)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.QUARTZ), 1), 0.25)
             .create("dirt");
 
+        RecipeBuilder.Trommel(RecipesGenerator.CORE_NAMESPACE)
+            .setInput(Blocks.MUD)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.BONE)), 4)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.STRING), 1, 3), 2)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.SLIMEBALL), 1, 4), 0.5)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLOTH), 1, 2), 0.5)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CHAINLINK), 1), 0.25)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 2), 30)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLAY), 1, 3), 20)
+            .create("mud");
+
         RecipeBuilder.Trommel(RecipesGenerator.CORE_NAMESPACE)
             .setInput(Blocks.GRAVEL)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.FLINT), 1, 2), 25)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.OLIVINE), 1, 3), 30)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 6), 25)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.ORE_RAW_IRON), 1, 2), 10)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 4), 15)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.ORE_RAW_IRON), 1, 2), 5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.DYE,1, DyeColor.BLUE.itemMeta), 2, 6), 5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.GUNPOWDER), 1), 5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.QUARTZ), 1), 0.5)
@@ -52,14 +63,14 @@ public class TrommelGenerator {
 
         RecipeBuilder.Trommel(RecipesGenerator.CORE_NAMESPACE)
             .setInput(Blocks.SAND)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.QUARTZ), 1, 3), 50)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLAY), 4, 8), 30)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 5), 25)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.BONE), 1, 3), 10)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.FLINT), 1, 3), 10)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.QUARTZ), 1, 2), 25)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.CLAY), 2, 5), 20)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.AMMO_PEBBLE), 1, 3), 15)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.BONE), 1, 2), 10)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.FLINT), 1, 2), 5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.GUNPOWDER), 1), 5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.OLIVINE), 1), 5)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.ORE_RAW_GOLD), 1), 1)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.ORE_RAW_GOLD), 1), 0.5)
             .create("sand");
 
         RecipeBuilder.Trommel(RecipesGenerator.CORE_NAMESPACE)
@@ -70,7 +81,7 @@ public class TrommelGenerator {
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.ORE_RAW_IRON), 1), 1)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.DUST_GLOWSTONE), 1, 6), 5)
             .addEntry(new WeightedRandomLootObject(new ItemStack(Items.QUARTZ), 1, 3), 5)
-            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.NETHERCOAL), 1), 0.5)
+            .addEntry(new WeightedRandomLootObject(new ItemStack(Items.NETHERCOAL), 1), 2)
             .create("soul_sand");
     }
 }
